# OrderCloud::AddressApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](AddressApi.md#create) | **POST** /buyers/{buyerID}/addresses | 
[**delete**](AddressApi.md#delete) | **DELETE** /buyers/{buyerID}/addresses/{addressID} | 
[**delete_assignment**](AddressApi.md#delete_assignment) | **DELETE** /buyers/{buyerID}/addresses/{addressID}/assignments | 
[**get**](AddressApi.md#get) | **GET** /buyers/{buyerID}/addresses/{addressID} | 
[**list**](AddressApi.md#list) | **GET** /buyers/{buyerID}/addresses | 
[**list_assignments**](AddressApi.md#list_assignments) | **GET** /buyers/{buyerID}/addresses/assignments | 
[**patch**](AddressApi.md#patch) | **PATCH** /buyers/{buyerID}/addresses/{addressID} | 
[**save_assignment**](AddressApi.md#save_assignment) | **POST** /buyers/{buyerID}/addresses/assignments | 
[**update**](AddressApi.md#update) | **PUT** /buyers/{buyerID}/addresses/{addressID} | 


# **create**
> Address create(buyer_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.create(buyer_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Address**](Address.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(buyer_id, address_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

address_id = "address_id_example" # String | ID of the address.


begin
  api_instance.delete(buyer_id, address_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **address_id** | **String**| ID of the address. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_assignment**
> delete_assignment(buyer_id, address_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

address_id = "address_id_example" # String | ID of the address.

opts = { 
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example" # String | ID of the user group.
}

begin
  api_instance.delete_assignment(buyer_id, address_id, opts)
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->delete_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **address_id** | **String**| ID of the address. | 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Address get(buyer_id, address_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

address_id = "address_id_example" # String | ID of the address.


begin
  result = api_instance.get(buyer_id, address_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **address_id** | **String**| ID of the address. | 

### Return type

[**Address**](Address.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListAddress list(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  search: "search_example", # String | Search of the address.
  search_on: ["search_on_example"], # Array<String> | Search on of the address.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the address.
  page: 56, # Integer | Page of the address.
  page_size: 56, # Integer | Page size of the address.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the address.
}

begin
  result = api_instance.list(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **search** | **String**| Search of the address. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the address. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the address. | [optional] 
 **page** | **Integer**| Page of the address. | [optional] 
 **page_size** | **Integer**| Page size of the address. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the address. | [optional] 

### Return type

[**ListAddress**](ListAddress.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_assignments**
> ListAddressAssignment list_assignments(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  address_id: "address_id_example", # String | ID of the address.
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example", # String | ID of the user group.
  level: "level_example", # String | Level of the address.
  is_shipping: true, # BOOLEAN | Is shipping of the address.
  is_billing: true, # BOOLEAN | Is billing of the address.
  page: 56, # Integer | Page of the address.
  page_size: 56 # Integer | Page size of the address.
}

begin
  result = api_instance.list_assignments(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->list_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **address_id** | **String**| ID of the address. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **level** | **String**| Level of the address. | [optional] 
 **is_shipping** | **BOOLEAN**| Is shipping of the address. | [optional] 
 **is_billing** | **BOOLEAN**| Is billing of the address. | [optional] 
 **page** | **Integer**| Page of the address. | [optional] 
 **page_size** | **Integer**| Page size of the address. | [optional] 

### Return type

[**ListAddressAssignment**](ListAddressAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Address patch(buyer_id, address_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

address_id = "address_id_example" # String | ID of the address.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.patch(buyer_id, address_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **address_id** | **String**| ID of the address. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Address**](Address.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_assignment**
> save_assignment(buyer_id, assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

assignment = OrderCloud::AddressAssignment.new # AddressAssignment | 


begin
  api_instance.save_assignment(buyer_id, assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->save_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **assignment** | [**AddressAssignment**](AddressAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> Address update(buyer_id, address_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AddressApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

address_id = "address_id_example" # String | ID of the address.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.update(buyer_id, address_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AddressApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **address_id** | **String**| ID of the address. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Address**](Address.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



