# OrderCloud::AdminAddressApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](AdminAddressApi.md#create) | **POST** /addresses | 
[**delete**](AdminAddressApi.md#delete) | **DELETE** /addresses/{addressID} | 
[**get**](AdminAddressApi.md#get) | **GET** /addresses/{addressID} | 
[**list**](AdminAddressApi.md#list) | **GET** /addresses | 
[**patch**](AdminAddressApi.md#patch) | **PATCH** /addresses/{addressID} | 
[**update**](AdminAddressApi.md#update) | **PUT** /addresses/{addressID} | 


# **create**
> Address create(address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AdminAddressApi.new

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.create(address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AdminAddressApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Address**](Address.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(address_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AdminAddressApi.new

address_id = "address_id_example" # String | ID of the address.


begin
  api_instance.delete(address_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling AdminAddressApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **address_id** | **String**| ID of the address. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Address get(address_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AdminAddressApi.new

address_id = "address_id_example" # String | ID of the address.


begin
  result = api_instance.get(address_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AdminAddressApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **address_id** | **String**| ID of the address. | 

### Return type

[**Address**](Address.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListAddress list(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AdminAddressApi.new

opts = { 
  search: "search_example", # String | Search of the admin address.
  search_on: ["search_on_example"], # Array<String> | Search on of the admin address.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the admin address.
  page: 56, # Integer | Page of the admin address.
  page_size: 56, # Integer | Page size of the admin address.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the admin address.
}

begin
  result = api_instance.list(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AdminAddressApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search** | **String**| Search of the admin address. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the admin address. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the admin address. | [optional] 
 **page** | **Integer**| Page of the admin address. | [optional] 
 **page_size** | **Integer**| Page size of the admin address. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the admin address. | [optional] 

### Return type

[**ListAddress**](ListAddress.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Address patch(address_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AdminAddressApi.new

address_id = "address_id_example" # String | ID of the address.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.patch(address_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AdminAddressApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **address_id** | **String**| ID of the address. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Address**](Address.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> Address update(address_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::AdminAddressApi.new

address_id = "address_id_example" # String | ID of the address.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.update(address_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling AdminAddressApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **address_id** | **String**| ID of the address. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Address**](Address.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



