# OrderCloud::BuyerApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](BuyerApi.md#create) | **POST** /buyers | 
[**delete**](BuyerApi.md#delete) | **DELETE** /buyers/{buyerID} | 
[**get**](BuyerApi.md#get) | **GET** /buyers/{buyerID} | 
[**list**](BuyerApi.md#list) | **GET** /buyers | 
[**patch**](BuyerApi.md#patch) | **PATCH** /buyers/{buyerID} | 
[**update**](BuyerApi.md#update) | **PUT** /buyers/{buyerID} | 


# **create**
> Buyer create(company)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::BuyerApi.new

company = OrderCloud::Buyer.new # Buyer | 


begin
  result = api_instance.create(company)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling BuyerApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **company** | [**Buyer**](Buyer.md)|  | 

### Return type

[**Buyer**](Buyer.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(buyer_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::BuyerApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.


begin
  api_instance.delete(buyer_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling BuyerApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Buyer get(buyer_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::BuyerApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.


begin
  result = api_instance.get(buyer_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling BuyerApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 

### Return type

[**Buyer**](Buyer.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListBuyer list(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::BuyerApi.new

opts = { 
  search: "search_example", # String | Search of the buyer.
  search_on: ["search_on_example"], # Array<String> | Search on of the buyer.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the buyer.
  page: 56, # Integer | Page of the buyer.
  page_size: 56, # Integer | Page size of the buyer.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the buyer.
}

begin
  result = api_instance.list(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling BuyerApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search** | **String**| Search of the buyer. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the buyer. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the buyer. | [optional] 
 **page** | **Integer**| Page of the buyer. | [optional] 
 **page_size** | **Integer**| Page size of the buyer. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the buyer. | [optional] 

### Return type

[**ListBuyer**](ListBuyer.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Buyer patch(buyer_id, company)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::BuyerApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

company = OrderCloud::Buyer.new # Buyer | 


begin
  result = api_instance.patch(buyer_id, company)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling BuyerApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **company** | [**Buyer**](Buyer.md)|  | 

### Return type

[**Buyer**](Buyer.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> Buyer update(buyer_id, company)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::BuyerApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

company = OrderCloud::Buyer.new # Buyer | 


begin
  result = api_instance.update(buyer_id, company)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling BuyerApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **company** | [**Buyer**](Buyer.md)|  | 

### Return type

[**Buyer**](Buyer.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



