# OrderCloud::CostCenterApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](CostCenterApi.md#create) | **POST** /buyers/{buyerID}/costcenters | 
[**delete**](CostCenterApi.md#delete) | **DELETE** /buyers/{buyerID}/costcenters/{costCenterID} | 
[**delete_assignment**](CostCenterApi.md#delete_assignment) | **DELETE** /buyers/{buyerID}/costcenters/{costCenterID}/assignments | 
[**get**](CostCenterApi.md#get) | **GET** /buyers/{buyerID}/costcenters/{costCenterID} | 
[**list**](CostCenterApi.md#list) | **GET** /buyers/{buyerID}/costcenters | 
[**list_assignments**](CostCenterApi.md#list_assignments) | **GET** /buyers/{buyerID}/costcenters/assignments | 
[**patch**](CostCenterApi.md#patch) | **PATCH** /buyers/{buyerID}/costcenters/{costCenterID} | 
[**save_assignment**](CostCenterApi.md#save_assignment) | **POST** /buyers/{buyerID}/costcenters/assignments | 
[**update**](CostCenterApi.md#update) | **PUT** /buyers/{buyerID}/costcenters/{costCenterID} | 


# **create**
> CostCenter create(buyer_id, cost_center)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

cost_center = OrderCloud::CostCenter.new # CostCenter | 


begin
  result = api_instance.create(buyer_id, cost_center)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **cost_center** | [**CostCenter**](CostCenter.md)|  | 

### Return type

[**CostCenter**](CostCenter.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(buyer_id, cost_center_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

cost_center_id = "cost_center_id_example" # String | ID of the cost center.


begin
  api_instance.delete(buyer_id, cost_center_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **cost_center_id** | **String**| ID of the cost center. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_assignment**
> delete_assignment(buyer_id, cost_center_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

cost_center_id = "cost_center_id_example" # String | ID of the cost center.

opts = { 
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example" # String | ID of the user group.
}

begin
  api_instance.delete_assignment(buyer_id, cost_center_id, opts)
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->delete_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **cost_center_id** | **String**| ID of the cost center. | 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> CostCenter get(buyer_id, cost_center_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

cost_center_id = "cost_center_id_example" # String | ID of the cost center.


begin
  result = api_instance.get(buyer_id, cost_center_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **cost_center_id** | **String**| ID of the cost center. | 

### Return type

[**CostCenter**](CostCenter.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListCostCenter list(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  search: "search_example", # String | Search of the cost center.
  search_on: ["search_on_example"], # Array<String> | Search on of the cost center.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the cost center.
  page: 56, # Integer | Page of the cost center.
  page_size: 56, # Integer | Page size of the cost center.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the cost center.
}

begin
  result = api_instance.list(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **search** | **String**| Search of the cost center. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the cost center. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the cost center. | [optional] 
 **page** | **Integer**| Page of the cost center. | [optional] 
 **page_size** | **Integer**| Page size of the cost center. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the cost center. | [optional] 

### Return type

[**ListCostCenter**](ListCostCenter.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_assignments**
> ListCostCenterAssignment list_assignments(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  cost_center_id: "cost_center_id_example", # String | ID of the cost center.
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example", # String | ID of the user group.
  level: "level_example", # String | Level of the cost center.
  page: 56, # Integer | Page of the cost center.
  page_size: 56 # Integer | Page size of the cost center.
}

begin
  result = api_instance.list_assignments(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->list_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **cost_center_id** | **String**| ID of the cost center. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **level** | **String**| Level of the cost center. | [optional] 
 **page** | **Integer**| Page of the cost center. | [optional] 
 **page_size** | **Integer**| Page size of the cost center. | [optional] 

### Return type

[**ListCostCenterAssignment**](ListCostCenterAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> CostCenter patch(buyer_id, cost_center_id, cost_center)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

cost_center_id = "cost_center_id_example" # String | ID of the cost center.

cost_center = OrderCloud::CostCenter.new # CostCenter | 


begin
  result = api_instance.patch(buyer_id, cost_center_id, cost_center)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **cost_center_id** | **String**| ID of the cost center. | 
 **cost_center** | [**CostCenter**](CostCenter.md)|  | 

### Return type

[**CostCenter**](CostCenter.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_assignment**
> save_assignment(buyer_id, assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

assignment = OrderCloud::CostCenterAssignment.new # CostCenterAssignment | 


begin
  api_instance.save_assignment(buyer_id, assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->save_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **assignment** | [**CostCenterAssignment**](CostCenterAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> CostCenter update(buyer_id, cost_center_id, cost_center)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CostCenterApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

cost_center_id = "cost_center_id_example" # String | ID of the cost center.

cost_center = OrderCloud::CostCenter.new # CostCenter | 


begin
  result = api_instance.update(buyer_id, cost_center_id, cost_center)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CostCenterApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **cost_center_id** | **String**| ID of the cost center. | 
 **cost_center** | [**CostCenter**](CostCenter.md)|  | 

### Return type

[**CostCenter**](CostCenter.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



