# OrderCloud::CreditCardApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](CreditCardApi.md#create) | **POST** /buyers/{buyerID}/creditcards | 
[**delete**](CreditCardApi.md#delete) | **DELETE** /buyers/{buyerID}/creditcards/{creditCardID} | 
[**delete_assignment**](CreditCardApi.md#delete_assignment) | **DELETE** /buyers/{buyerID}/creditcards/{creditCardID}/assignments | 
[**get**](CreditCardApi.md#get) | **GET** /buyers/{buyerID}/creditcards/{creditCardID} | 
[**list**](CreditCardApi.md#list) | **GET** /buyers/{buyerID}/creditcards | 
[**list_assignments**](CreditCardApi.md#list_assignments) | **GET** /buyers/{buyerID}/creditcards/assignments | 
[**patch**](CreditCardApi.md#patch) | **PATCH** /buyers/{buyerID}/creditcards/{creditCardID} | 
[**save_assignment**](CreditCardApi.md#save_assignment) | **POST** /buyers/{buyerID}/creditcards/assignments | 
[**update**](CreditCardApi.md#update) | **PUT** /buyers/{buyerID}/creditcards/{creditCardID} | 


# **create**
> CreditCard create(buyer_id, card)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

card = OrderCloud::CreditCard.new # CreditCard | 


begin
  result = api_instance.create(buyer_id, card)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **card** | [**CreditCard**](CreditCard.md)|  | 

### Return type

[**CreditCard**](CreditCard.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(buyer_id, credit_card_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

credit_card_id = "credit_card_id_example" # String | ID of the credit card.


begin
  api_instance.delete(buyer_id, credit_card_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **credit_card_id** | **String**| ID of the credit card. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_assignment**
> delete_assignment(buyer_id, credit_card_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

credit_card_id = "credit_card_id_example" # String | ID of the credit card.

opts = { 
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example" # String | ID of the user group.
}

begin
  api_instance.delete_assignment(buyer_id, credit_card_id, opts)
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->delete_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **credit_card_id** | **String**| ID of the credit card. | 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> CreditCard get(buyer_id, credit_card_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

credit_card_id = "credit_card_id_example" # String | ID of the credit card.


begin
  result = api_instance.get(buyer_id, credit_card_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **credit_card_id** | **String**| ID of the credit card. | 

### Return type

[**CreditCard**](CreditCard.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListCreditCard list(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  search: "search_example", # String | Search of the credit card.
  search_on: ["search_on_example"], # Array<String> | Search on of the credit card.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the credit card.
  page: 56, # Integer | Page of the credit card.
  page_size: 56, # Integer | Page size of the credit card.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the credit card.
}

begin
  result = api_instance.list(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **search** | **String**| Search of the credit card. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the credit card. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the credit card. | [optional] 
 **page** | **Integer**| Page of the credit card. | [optional] 
 **page_size** | **Integer**| Page size of the credit card. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the credit card. | [optional] 

### Return type

[**ListCreditCard**](ListCreditCard.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_assignments**
> ListCreditCardAssignment list_assignments(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  credit_card_id: "credit_card_id_example", # String | ID of the credit card.
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example", # String | ID of the user group.
  level: "level_example", # String | Level of the credit card.
  page: 56, # Integer | Page of the credit card.
  page_size: 56 # Integer | Page size of the credit card.
}

begin
  result = api_instance.list_assignments(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->list_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **credit_card_id** | **String**| ID of the credit card. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **level** | **String**| Level of the credit card. | [optional] 
 **page** | **Integer**| Page of the credit card. | [optional] 
 **page_size** | **Integer**| Page size of the credit card. | [optional] 

### Return type

[**ListCreditCardAssignment**](ListCreditCardAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> CreditCard patch(buyer_id, credit_card_id, card)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

credit_card_id = "credit_card_id_example" # String | ID of the credit card.

card = OrderCloud::CreditCard.new # CreditCard | 


begin
  result = api_instance.patch(buyer_id, credit_card_id, card)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **credit_card_id** | **String**| ID of the credit card. | 
 **card** | [**CreditCard**](CreditCard.md)|  | 

### Return type

[**CreditCard**](CreditCard.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_assignment**
> save_assignment(buyer_id, assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

assignment = OrderCloud::CreditCardAssignment.new # CreditCardAssignment | 


begin
  api_instance.save_assignment(buyer_id, assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->save_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **assignment** | [**CreditCardAssignment**](CreditCardAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> CreditCard update(buyer_id, credit_card_id, card)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::CreditCardApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

credit_card_id = "credit_card_id_example" # String | ID of the credit card.

card = OrderCloud::CreditCard.new # CreditCard | 


begin
  result = api_instance.update(buyer_id, credit_card_id, card)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling CreditCardApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **credit_card_id** | **String**| ID of the credit card. | 
 **card** | [**CreditCard**](CreditCard.md)|  | 

### Return type

[**CreditCard**](CreditCard.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



