# OrderCloud::LineItemApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](LineItemApi.md#create) | **POST** /orders/{direction}/{orderID}/lineitems | 
[**delete**](LineItemApi.md#delete) | **DELETE** /orders/{direction}/{orderID}/lineitems/{lineItemID} | 
[**get**](LineItemApi.md#get) | **GET** /orders/{direction}/{orderID}/lineitems/{lineItemID} | 
[**list**](LineItemApi.md#list) | **GET** /orders/{direction}/{orderID}/lineitems | 
[**patch**](LineItemApi.md#patch) | **PATCH** /orders/{direction}/{orderID}/lineitems/{lineItemID} | 
[**patch_shipping_address**](LineItemApi.md#patch_shipping_address) | **PATCH** /orders/{direction}/{orderID}/lineitems/{lineItemID}/shipto | 
[**set_shipping_address**](LineItemApi.md#set_shipping_address) | **PUT** /orders/{direction}/{orderID}/lineitems/{lineItemID}/shipto | 
[**update**](LineItemApi.md#update) | **PUT** /orders/{direction}/{orderID}/lineitems/{lineItemID} | 


# **create**
> LineItem create(direction, order_id, line_item)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::LineItemApi.new

direction = "direction_example" # String | Direction of the line item. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

line_item = OrderCloud::LineItem.new # LineItem | 


begin
  result = api_instance.create(direction, order_id, line_item)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling LineItemApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the line item. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **line_item** | [**LineItem**](LineItem.md)|  | 

### Return type

[**LineItem**](LineItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(direction, order_id, line_item_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::LineItemApi.new

direction = "direction_example" # String | Direction of the line item. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

line_item_id = "line_item_id_example" # String | ID of the line item.


begin
  api_instance.delete(direction, order_id, line_item_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling LineItemApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the line item. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **line_item_id** | **String**| ID of the line item. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> LineItem get(direction, order_id, line_item_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::LineItemApi.new

direction = "direction_example" # String | Direction of the line item. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

line_item_id = "line_item_id_example" # String | ID of the line item.


begin
  result = api_instance.get(direction, order_id, line_item_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling LineItemApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the line item. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **line_item_id** | **String**| ID of the line item. | 

### Return type

[**LineItem**](LineItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListLineItem list(direction, order_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::LineItemApi.new

direction = "direction_example" # String | Direction of the line item. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

opts = { 
  search: "search_example", # String | Search of the line item.
  search_on: ["search_on_example"], # Array<String> | Search on of the line item.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the line item.
  page: 56, # Integer | Page of the line item.
  page_size: 56, # Integer | Page size of the line item.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the line item.
}

begin
  result = api_instance.list(direction, order_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling LineItemApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the line item. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **search** | **String**| Search of the line item. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the line item. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the line item. | [optional] 
 **page** | **Integer**| Page of the line item. | [optional] 
 **page_size** | **Integer**| Page size of the line item. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the line item. | [optional] 

### Return type

[**ListLineItem**](ListLineItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> LineItem patch(direction, order_id, line_item_id, partial_line_item)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::LineItemApi.new

direction = "direction_example" # String | Direction of the line item. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

line_item_id = "line_item_id_example" # String | ID of the line item.

partial_line_item = OrderCloud::LineItem.new # LineItem | 


begin
  result = api_instance.patch(direction, order_id, line_item_id, partial_line_item)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling LineItemApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the line item. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **line_item_id** | **String**| ID of the line item. | 
 **partial_line_item** | [**LineItem**](LineItem.md)|  | 

### Return type

[**LineItem**](LineItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch_shipping_address**
> LineItem patch_shipping_address(direction, order_id, line_item_id, partial_address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::LineItemApi.new

direction = "direction_example" # String | Direction of the line item. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

line_item_id = "line_item_id_example" # String | ID of the line item.

partial_address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.patch_shipping_address(direction, order_id, line_item_id, partial_address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling LineItemApi->patch_shipping_address: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the line item. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **line_item_id** | **String**| ID of the line item. | 
 **partial_address** | [**Address**](Address.md)|  | 

### Return type

[**LineItem**](LineItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **set_shipping_address**
> LineItem set_shipping_address(direction, order_id, line_item_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::LineItemApi.new

direction = "direction_example" # String | Direction of the line item. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

line_item_id = "line_item_id_example" # String | ID of the line item.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.set_shipping_address(direction, order_id, line_item_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling LineItemApi->set_shipping_address: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the line item. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **line_item_id** | **String**| ID of the line item. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**LineItem**](LineItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> LineItem update(direction, order_id, line_item_id, line_item)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::LineItemApi.new

direction = "direction_example" # String | Direction of the line item. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

line_item_id = "line_item_id_example" # String | ID of the line item.

line_item = OrderCloud::LineItem.new # LineItem | 


begin
  result = api_instance.update(direction, order_id, line_item_id, line_item)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling LineItemApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the line item. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **line_item_id** | **String**| ID of the line item. | 
 **line_item** | [**LineItem**](LineItem.md)|  | 

### Return type

[**LineItem**](LineItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



