# OrderCloud::OrderApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**add_promotion**](OrderApi.md#add_promotion) | **POST** /orders/{direction}/{orderID}/promotions/{promoCode} | 
[**approve**](OrderApi.md#approve) | **POST** /orders/{direction}/{orderID}/approve | 
[**cancel**](OrderApi.md#cancel) | **POST** /orders/{direction}/{orderID}/cancel | 
[**create**](OrderApi.md#create) | **POST** /orders/{direction} | 
[**decline**](OrderApi.md#decline) | **POST** /orders/{direction}/{orderID}/decline | 
[**delete**](OrderApi.md#delete) | **DELETE** /orders/{direction}/{orderID} | 
[**get**](OrderApi.md#get) | **GET** /orders/{direction}/{orderID} | 
[**list**](OrderApi.md#list) | **GET** /orders/{direction} | 
[**list_approvals**](OrderApi.md#list_approvals) | **GET** /orders/{direction}/{orderID}/approvals | 
[**list_eligible_approvers**](OrderApi.md#list_eligible_approvers) | **GET** /orders/{direction}/{orderID}/eligibleapprovers | 
[**list_promotions**](OrderApi.md#list_promotions) | **GET** /orders/{direction}/{orderID}/promotions | 
[**patch**](OrderApi.md#patch) | **PATCH** /orders/{direction}/{orderID} | 
[**patch_billing_address**](OrderApi.md#patch_billing_address) | **PATCH** /orders/{direction}/{orderID}/billto | 
[**patch_shipping_address**](OrderApi.md#patch_shipping_address) | **PATCH** /orders/{direction}/{orderID}/shipto | 
[**remove_promotion**](OrderApi.md#remove_promotion) | **DELETE** /orders/{direction}/{orderID}/promotions/{promoCode} | 
[**set_billing_address**](OrderApi.md#set_billing_address) | **PUT** /orders/{direction}/{orderID}/billto | 
[**set_shipping_address**](OrderApi.md#set_shipping_address) | **PUT** /orders/{direction}/{orderID}/shipto | 
[**ship**](OrderApi.md#ship) | **POST** /orders/{direction}/{orderID}/ship | 
[**submit**](OrderApi.md#submit) | **POST** /orders/{direction}/{orderID}/submit | 
[**update**](OrderApi.md#update) | **PUT** /orders/{direction}/{orderID} | 


# **add_promotion**
> Promotion add_promotion(direction, order_id, promo_code)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

promo_code = "promo_code_example" # String | Promo code of the order.


begin
  result = api_instance.add_promotion(direction, order_id, promo_code)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->add_promotion: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **promo_code** | **String**| Promo code of the order. | 

### Return type

[**Promotion**](Promotion.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **approve**
> Order approve(direction, order_id, info)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

info = OrderCloud::OrderApprovalInfo.new # OrderApprovalInfo | 


begin
  result = api_instance.approve(direction, order_id, info)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->approve: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **info** | [**OrderApprovalInfo**](OrderApprovalInfo.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **cancel**
> Order cancel(direction, order_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.


begin
  result = api_instance.cancel(direction, order_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->cancel: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **create**
> Order create(direction, order)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order = OrderCloud::Order.new # Order | 


begin
  result = api_instance.create(direction, order)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order** | [**Order**](Order.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **decline**
> Order decline(direction, order_id, info)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

info = OrderCloud::OrderApprovalInfo.new # OrderApprovalInfo | 


begin
  result = api_instance.decline(direction, order_id, info)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->decline: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **info** | [**OrderApprovalInfo**](OrderApprovalInfo.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(direction, order_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.


begin
  api_instance.delete(direction, order_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Order get(direction, order_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.


begin
  result = api_instance.get(direction, order_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListOrder list(direction, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

opts = { 
  buyer_id: "buyer_id_example", # String | ID of the buyer.
  supplier_id: "supplier_id_example", # String | ID of the supplier.
  from: "from_example", # String | Lower bound of date range that the order was created.
  to: "to_example", # String | Upper bound of date range that the order was created.
  search: "search_example", # String | Search of the order.
  search_on: ["search_on_example"], # Array<String> | Search on of the order.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the order.
  page: 56, # Integer | Page of the order.
  page_size: 56, # Integer | Page size of the order.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the order.
}

begin
  result = api_instance.list(direction, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **buyer_id** | **String**| ID of the buyer. | [optional] 
 **supplier_id** | **String**| ID of the supplier. | [optional] 
 **from** | **String**| Lower bound of date range that the order was created. | [optional] 
 **to** | **String**| Upper bound of date range that the order was created. | [optional] 
 **search** | **String**| Search of the order. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the order. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the order. | [optional] 
 **page** | **Integer**| Page of the order. | [optional] 
 **page_size** | **Integer**| Page size of the order. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the order. | [optional] 

### Return type

[**ListOrder**](ListOrder.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_approvals**
> ListOrderApproval list_approvals(direction, order_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

opts = { 
  search: "search_example", # String | Search of the order.
  search_on: ["search_on_example"], # Array<String> | Search on of the order.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the order.
  page: 56, # Integer | Page of the order.
  page_size: 56, # Integer | Page size of the order.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the order.
}

begin
  result = api_instance.list_approvals(direction, order_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->list_approvals: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **search** | **String**| Search of the order. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the order. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the order. | [optional] 
 **page** | **Integer**| Page of the order. | [optional] 
 **page_size** | **Integer**| Page size of the order. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the order. | [optional] 

### Return type

[**ListOrderApproval**](ListOrderApproval.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_eligible_approvers**
> ListUser list_eligible_approvers(direction, order_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

opts = { 
  search: "search_example", # String | Search of the order.
  search_on: ["search_on_example"], # Array<String> | Search on of the order.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the order.
  page: 56, # Integer | Page of the order.
  page_size: 56, # Integer | Page size of the order.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the order.
}

begin
  result = api_instance.list_eligible_approvers(direction, order_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->list_eligible_approvers: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **search** | **String**| Search of the order. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the order. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the order. | [optional] 
 **page** | **Integer**| Page of the order. | [optional] 
 **page_size** | **Integer**| Page size of the order. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the order. | [optional] 

### Return type

[**ListUser**](ListUser.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_promotions**
> ListOrderPromotion list_promotions(direction, order_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

opts = { 
  search: "search_example", # String | Search of the order.
  search_on: ["search_on_example"], # Array<String> | Search on of the order.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the order.
  page: 56, # Integer | Page of the order.
  page_size: 56, # Integer | Page size of the order.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the order.
}

begin
  result = api_instance.list_promotions(direction, order_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->list_promotions: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **search** | **String**| Search of the order. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the order. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the order. | [optional] 
 **page** | **Integer**| Page of the order. | [optional] 
 **page_size** | **Integer**| Page size of the order. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the order. | [optional] 

### Return type

[**ListOrderPromotion**](ListOrderPromotion.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Order patch(direction, order_id, partial_order)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

partial_order = OrderCloud::Order.new # Order | 


begin
  result = api_instance.patch(direction, order_id, partial_order)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **partial_order** | [**Order**](Order.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch_billing_address**
> Order patch_billing_address(direction, order_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.patch_billing_address(direction, order_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->patch_billing_address: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch_shipping_address**
> Order patch_shipping_address(direction, order_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.patch_shipping_address(direction, order_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->patch_shipping_address: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **remove_promotion**
> Order remove_promotion(direction, order_id, promo_code)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

promo_code = "promo_code_example" # String | Promo code of the order.


begin
  result = api_instance.remove_promotion(direction, order_id, promo_code)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->remove_promotion: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **promo_code** | **String**| Promo code of the order. | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **set_billing_address**
> Order set_billing_address(direction, order_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.set_billing_address(direction, order_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->set_billing_address: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **set_shipping_address**
> Order set_shipping_address(direction, order_id, address)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

address = OrderCloud::Address.new # Address | 


begin
  result = api_instance.set_shipping_address(direction, order_id, address)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->set_shipping_address: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **address** | [**Address**](Address.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **ship**
> Order ship(direction, order_id, shipment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

shipment = OrderCloud::BuyerShipment.new # BuyerShipment | 


begin
  result = api_instance.ship(direction, order_id, shipment)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->ship: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **shipment** | [**BuyerShipment**](BuyerShipment.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **submit**
> Order submit(direction, order_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.


begin
  result = api_instance.submit(direction, order_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->submit: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> Order update(direction, order_id, order)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::OrderApi.new

direction = "direction_example" # String | Direction of the order. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

order = OrderCloud::Order.new # Order | 


begin
  result = api_instance.update(direction, order_id, order)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling OrderApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the order. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **order** | [**Order**](Order.md)|  | 

### Return type

[**Order**](Order.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



