# OrderCloud::PaymentApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](PaymentApi.md#create) | **POST** /orders/{direction}/{orderID}/payments | 
[**create_transaction**](PaymentApi.md#create_transaction) | **POST** /orders/{direction}/{orderID}/payments/{paymentID}/transactions | 
[**delete**](PaymentApi.md#delete) | **DELETE** /orders/{direction}/{orderID}/payments/{paymentID} | 
[**delete_transaction**](PaymentApi.md#delete_transaction) | **DELETE** /orders/{direction}/{orderID}/payments/{paymentID}/transactions/{transactionID} | 
[**get**](PaymentApi.md#get) | **GET** /orders/{direction}/{orderID}/payments/{paymentID} | 
[**list**](PaymentApi.md#list) | **GET** /orders/{direction}/{orderID}/payments | 
[**patch**](PaymentApi.md#patch) | **PATCH** /orders/{direction}/{orderID}/payments/{paymentID} | 


# **create**
> Payment create(direction, order_id, payment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::PaymentApi.new

direction = "direction_example" # String | Direction of the payment. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

payment = OrderCloud::Payment.new # Payment | 


begin
  result = api_instance.create(direction, order_id, payment)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling PaymentApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the payment. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **payment** | [**Payment**](Payment.md)|  | 

### Return type

[**Payment**](Payment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **create_transaction**
> Payment create_transaction(direction, order_id, payment_id, transaction)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::PaymentApi.new

direction = "direction_example" # String | Direction of the payment. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

payment_id = "payment_id_example" # String | ID of the payment.

transaction = OrderCloud::PaymentTransaction.new # PaymentTransaction | 


begin
  result = api_instance.create_transaction(direction, order_id, payment_id, transaction)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling PaymentApi->create_transaction: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the payment. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **payment_id** | **String**| ID of the payment. | 
 **transaction** | [**PaymentTransaction**](PaymentTransaction.md)|  | 

### Return type

[**Payment**](Payment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(direction, order_id, payment_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::PaymentApi.new

direction = "direction_example" # String | Direction of the payment. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

payment_id = "payment_id_example" # String | ID of the payment.


begin
  api_instance.delete(direction, order_id, payment_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling PaymentApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the payment. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **payment_id** | **String**| ID of the payment. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_transaction**
> delete_transaction(direction, order_id, payment_id, transaction_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::PaymentApi.new

direction = "direction_example" # String | Direction of the payment. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

payment_id = "payment_id_example" # String | ID of the payment.

transaction_id = "transaction_id_example" # String | ID of the transaction.


begin
  api_instance.delete_transaction(direction, order_id, payment_id, transaction_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling PaymentApi->delete_transaction: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the payment. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **payment_id** | **String**| ID of the payment. | 
 **transaction_id** | **String**| ID of the transaction. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Payment get(direction, order_id, payment_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::PaymentApi.new

direction = "direction_example" # String | Direction of the payment. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

payment_id = "payment_id_example" # String | ID of the payment.


begin
  result = api_instance.get(direction, order_id, payment_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling PaymentApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the payment. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **payment_id** | **String**| ID of the payment. | 

### Return type

[**Payment**](Payment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListPayment list(direction, order_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::PaymentApi.new

direction = "direction_example" # String | Direction of the payment. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

opts = { 
  search: "search_example", # String | Search of the payment.
  search_on: ["search_on_example"], # Array<String> | Search on of the payment.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the payment.
  page: 56, # Integer | Page of the payment.
  page_size: 56, # Integer | Page size of the payment.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the payment.
}

begin
  result = api_instance.list(direction, order_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling PaymentApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the payment. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **search** | **String**| Search of the payment. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the payment. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the payment. | [optional] 
 **page** | **Integer**| Page of the payment. | [optional] 
 **page_size** | **Integer**| Page size of the payment. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the payment. | [optional] 

### Return type

[**ListPayment**](ListPayment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Payment patch(direction, order_id, payment_id, partial_payment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::PaymentApi.new

direction = "direction_example" # String | Direction of the payment. Possible values: Incoming, Outgoing.

order_id = "order_id_example" # String | ID of the order.

payment_id = "payment_id_example" # String | ID of the payment.

partial_payment = OrderCloud::Payment.new # Payment | 


begin
  result = api_instance.patch(direction, order_id, payment_id, partial_payment)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling PaymentApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **direction** | **String**| Direction of the payment. Possible values: Incoming, Outgoing. | 
 **order_id** | **String**| ID of the order. | 
 **payment_id** | **String**| ID of the payment. | 
 **partial_payment** | [**Payment**](Payment.md)|  | 

### Return type

[**Payment**](Payment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



