# OrderCloud::ProductApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ProductApi.md#create) | **POST** /products | 
[**delete**](ProductApi.md#delete) | **DELETE** /products/{productID} | 
[**delete_assignment**](ProductApi.md#delete_assignment) | **DELETE** /products/{productID}/assignments/{buyerID} | 
[**generate_variants**](ProductApi.md#generate_variants) | **POST** /products/{productID}/variants/generate | 
[**get**](ProductApi.md#get) | **GET** /products/{productID} | 
[**get_variant**](ProductApi.md#get_variant) | **GET** /products/{productID}/variants/{variantID} | 
[**list**](ProductApi.md#list) | **GET** /products | 
[**list_assignments**](ProductApi.md#list_assignments) | **GET** /products/assignments | 
[**list_suppliers**](ProductApi.md#list_suppliers) | **GET** /products/{productID}/suppliers | 
[**list_variants**](ProductApi.md#list_variants) | **GET** /products/{productID}/variants | 
[**patch**](ProductApi.md#patch) | **PATCH** /products/{productID} | 
[**patch_variant**](ProductApi.md#patch_variant) | **PATCH** /products/{productID}/variants/{variantID} | 
[**remove_supplier**](ProductApi.md#remove_supplier) | **DELETE** /products/{productID}/suppliers/{supplierID} | 
[**save_assignment**](ProductApi.md#save_assignment) | **POST** /products/assignments | 
[**save_supplier**](ProductApi.md#save_supplier) | **PUT** /products/{productID}/suppliers/{supplierID} | 
[**update**](ProductApi.md#update) | **PUT** /products/{productID} | 
[**update_variant**](ProductApi.md#update_variant) | **PUT** /products/{productID}/variants/{variantID} | 


# **create**
> Product create(product)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product = OrderCloud::Product.new # Product | 


begin
  result = api_instance.create(product)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product** | [**Product**](Product.md)|  | 

### Return type

[**Product**](Product.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(product_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.


begin
  api_instance.delete(product_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_assignment**
> delete_assignment(product_id, buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example" # String | ID of the user group.
}

begin
  api_instance.delete_assignment(product_id, buyer_id, opts)
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->delete_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **buyer_id** | **String**| ID of the buyer. | 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **generate_variants**
> Product generate_variants(product_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

opts = { 
  overwrite_existing: true # BOOLEAN | Overwrite existing of the product.
}

begin
  result = api_instance.generate_variants(product_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->generate_variants: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **overwrite_existing** | **BOOLEAN**| Overwrite existing of the product. | [optional] 

### Return type

[**Product**](Product.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Product get(product_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.


begin
  result = api_instance.get(product_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 

### Return type

[**Product**](Product.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get_variant**
> Variant get_variant(product_id, variant_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

variant_id = "variant_id_example" # String | ID of the variant.


begin
  result = api_instance.get_variant(product_id, variant_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->get_variant: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **variant_id** | **String**| ID of the variant. | 

### Return type

[**Variant**](Variant.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListProduct list(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

opts = { 
  catalog_id: "catalog_id_example", # String | ID of the catalog.
  category_id: "category_id_example", # String | ID of the category.
  supplier_id: "supplier_id_example", # String | ID of the supplier.
  search: "search_example", # String | Search of the product.
  search_on: ["search_on_example"], # Array<String> | Search on of the product.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the product.
  page: 56, # Integer | Page of the product.
  page_size: 56, # Integer | Page size of the product.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the product.
}

begin
  result = api_instance.list(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **catalog_id** | **String**| ID of the catalog. | [optional] 
 **category_id** | **String**| ID of the category. | [optional] 
 **supplier_id** | **String**| ID of the supplier. | [optional] 
 **search** | **String**| Search of the product. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the product. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the product. | [optional] 
 **page** | **Integer**| Page of the product. | [optional] 
 **page_size** | **Integer**| Page size of the product. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the product. | [optional] 

### Return type

[**ListProduct**](ListProduct.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_assignments**
> ListProductAssignment list_assignments(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

opts = { 
  product_id: "product_id_example", # String | ID of the product.
  price_schedule_id: "price_schedule_id_example", # String | ID of the price schedule.
  buyer_id: "buyer_id_example", # String | ID of the buyer.
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example", # String | ID of the user group.
  level: "level_example", # String | Level of the product.
  page: 56, # Integer | Page of the product.
  page_size: 56 # Integer | Page size of the product.
}

begin
  result = api_instance.list_assignments(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->list_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | [optional] 
 **price_schedule_id** | **String**| ID of the price schedule. | [optional] 
 **buyer_id** | **String**| ID of the buyer. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **level** | **String**| Level of the product. | [optional] 
 **page** | **Integer**| Page of the product. | [optional] 
 **page_size** | **Integer**| Page size of the product. | [optional] 

### Return type

[**ListProductAssignment**](ListProductAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_suppliers**
> ListSupplier list_suppliers(product_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

opts = { 
  search: "search_example", # String | Search of the product.
  search_on: ["search_on_example"], # Array<String> | Search on of the product.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the product.
  page: 56, # Integer | Page of the product.
  page_size: 56, # Integer | Page size of the product.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the product.
}

begin
  result = api_instance.list_suppliers(product_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->list_suppliers: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **search** | **String**| Search of the product. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the product. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the product. | [optional] 
 **page** | **Integer**| Page of the product. | [optional] 
 **page_size** | **Integer**| Page size of the product. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the product. | [optional] 

### Return type

[**ListSupplier**](ListSupplier.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_variants**
> ListVariant list_variants(product_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

opts = { 
  search: "search_example", # String | Search of the product.
  search_on: ["search_on_example"], # Array<String> | Search on of the product.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the product.
  page: 56, # Integer | Page of the product.
  page_size: 56, # Integer | Page size of the product.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the product.
}

begin
  result = api_instance.list_variants(product_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->list_variants: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **search** | **String**| Search of the product. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the product. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the product. | [optional] 
 **page** | **Integer**| Page of the product. | [optional] 
 **page_size** | **Integer**| Page size of the product. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the product. | [optional] 

### Return type

[**ListVariant**](ListVariant.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Product patch(product_id, product)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

product = OrderCloud::Product.new # Product | 


begin
  result = api_instance.patch(product_id, product)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **product** | [**Product**](Product.md)|  | 

### Return type

[**Product**](Product.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch_variant**
> Variant patch_variant(product_id, variant_id, variant)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

variant_id = "variant_id_example" # String | ID of the variant.

variant = OrderCloud::Variant.new # Variant | 


begin
  result = api_instance.patch_variant(product_id, variant_id, variant)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->patch_variant: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **variant_id** | **String**| ID of the variant. | 
 **variant** | [**Variant**](Variant.md)|  | 

### Return type

[**Variant**](Variant.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **remove_supplier**
> remove_supplier(product_id, supplier_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

supplier_id = "supplier_id_example" # String | ID of the supplier.


begin
  api_instance.remove_supplier(product_id, supplier_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->remove_supplier: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **supplier_id** | **String**| ID of the supplier. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_assignment**
> save_assignment(product_assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_assignment = OrderCloud::ProductAssignment.new # ProductAssignment | 


begin
  api_instance.save_assignment(product_assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->save_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_assignment** | [**ProductAssignment**](ProductAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_supplier**
> save_supplier(product_id, supplier_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

supplier_id = "supplier_id_example" # String | ID of the supplier.


begin
  api_instance.save_supplier(product_id, supplier_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->save_supplier: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **supplier_id** | **String**| ID of the supplier. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> Product update(product_id, product)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

product = OrderCloud::Product.new # Product | 


begin
  result = api_instance.update(product_id, product)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **product** | [**Product**](Product.md)|  | 

### Return type

[**Product**](Product.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update_variant**
> Variant update_variant(product_id, variant_id, variant)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ProductApi.new

product_id = "product_id_example" # String | ID of the product.

variant_id = "variant_id_example" # String | ID of the variant.

variant = OrderCloud::Variant.new # Variant | 


begin
  result = api_instance.update_variant(product_id, variant_id, variant)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ProductApi->update_variant: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_id** | **String**| ID of the product. | 
 **variant_id** | **String**| ID of the variant. | 
 **variant** | [**Variant**](Variant.md)|  | 

### Return type

[**Variant**](Variant.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



