# OrderCloud::SecurityProfileApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**delete_assignment**](SecurityProfileApi.md#delete_assignment) | **DELETE** /securityprofiles/{securityProfileID}/assignments | 
[**get**](SecurityProfileApi.md#get) | **GET** /securityprofiles/{securityProfileID} | 
[**list**](SecurityProfileApi.md#list) | **GET** /securityprofiles | 
[**list_assignments**](SecurityProfileApi.md#list_assignments) | **GET** /securityprofiles/assignments | 
[**save_assignment**](SecurityProfileApi.md#save_assignment) | **POST** /securityprofiles/assignments | 


# **delete_assignment**
> delete_assignment(security_profile_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SecurityProfileApi.new

security_profile_id = "security_profile_id_example" # String | ID of the security profile.

opts = { 
  buyer_id: "buyer_id_example", # String | ID of the buyer.
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example" # String | ID of the user group.
}

begin
  api_instance.delete_assignment(security_profile_id, opts)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SecurityProfileApi->delete_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **security_profile_id** | **String**| ID of the security profile. | 
 **buyer_id** | **String**| ID of the buyer. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> SecurityProfile get(security_profile_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SecurityProfileApi.new

security_profile_id = "security_profile_id_example" # String | ID of the security profile.


begin
  result = api_instance.get(security_profile_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SecurityProfileApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **security_profile_id** | **String**| ID of the security profile. | 

### Return type

[**SecurityProfile**](SecurityProfile.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListSecurityProfile list(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SecurityProfileApi.new

opts = { 
  search: "search_example", # String | Search of the security profile.
  search_on: ["search_on_example"], # Array<String> | Search on of the security profile.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the security profile.
  page: 56, # Integer | Page of the security profile.
  page_size: 56, # Integer | Page size of the security profile.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the security profile.
}

begin
  result = api_instance.list(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SecurityProfileApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search** | **String**| Search of the security profile. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the security profile. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the security profile. | [optional] 
 **page** | **Integer**| Page of the security profile. | [optional] 
 **page_size** | **Integer**| Page size of the security profile. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the security profile. | [optional] 

### Return type

[**ListSecurityProfile**](ListSecurityProfile.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_assignments**
> ListSecurityProfileAssignment list_assignments(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SecurityProfileApi.new

opts = { 
  buyer_id: "buyer_id_example", # String | ID of the buyer.
  supplier_id: "supplier_id_example", # String | ID of the supplier.
  security_profile_id: "security_profile_id_example", # String | ID of the security profile.
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example", # String | ID of the user group.
  commerce_role: "commerce_role_example", # String | Commerce role of the security profile.
  level: "level_example", # String | Level of the security profile.
  page: 56, # Integer | Page of the security profile.
  page_size: 56 # Integer | Page size of the security profile.
}

begin
  result = api_instance.list_assignments(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SecurityProfileApi->list_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | [optional] 
 **supplier_id** | **String**| ID of the supplier. | [optional] 
 **security_profile_id** | **String**| ID of the security profile. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **commerce_role** | **String**| Commerce role of the security profile. | [optional] 
 **level** | **String**| Level of the security profile. | [optional] 
 **page** | **Integer**| Page of the security profile. | [optional] 
 **page_size** | **Integer**| Page size of the security profile. | [optional] 

### Return type

[**ListSecurityProfileAssignment**](ListSecurityProfileAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_assignment**
> save_assignment(assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SecurityProfileApi.new

assignment = OrderCloud::SecurityProfileAssignment.new # SecurityProfileAssignment | 


begin
  api_instance.save_assignment(assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SecurityProfileApi->save_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **assignment** | [**SecurityProfileAssignment**](SecurityProfileAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



