# OrderCloud::ShipmentApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ShipmentApi.md#create) | **POST** /shipments | 
[**delete**](ShipmentApi.md#delete) | **DELETE** /shipments/{shipmentID} | 
[**delete_item**](ShipmentApi.md#delete_item) | **DELETE** /shipments/{shipmentID}/items/{orderID}/{lineItemID} | 
[**get**](ShipmentApi.md#get) | **GET** /shipments/{shipmentID} | 
[**get_item**](ShipmentApi.md#get_item) | **GET** /shipments/{shipmentID}/items/{orderID}/{lineItemID} | 
[**list**](ShipmentApi.md#list) | **GET** /shipments | 
[**list_items**](ShipmentApi.md#list_items) | **GET** /shipments/{shipmentID}/items | 
[**patch**](ShipmentApi.md#patch) | **PATCH** /shipments/{shipmentID} | 
[**save_item**](ShipmentApi.md#save_item) | **POST** /shipments/{shipmentID}/items | 
[**update**](ShipmentApi.md#update) | **PUT** /shipments/{shipmentID} | 


# **create**
> Shipment create(shipment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment = OrderCloud::Shipment.new # Shipment | 


begin
  result = api_instance.create(shipment)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment** | [**Shipment**](Shipment.md)|  | 

### Return type

[**Shipment**](Shipment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(shipment_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment_id = "shipment_id_example" # String | ID of the shipment.


begin
  api_instance.delete(shipment_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment_id** | **String**| ID of the shipment. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_item**
> delete_item(shipment_id, order_id, line_item_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment_id = "shipment_id_example" # String | ID of the shipment.

order_id = "order_id_example" # String | ID of the order.

line_item_id = "line_item_id_example" # String | ID of the line item.


begin
  api_instance.delete_item(shipment_id, order_id, line_item_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->delete_item: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment_id** | **String**| ID of the shipment. | 
 **order_id** | **String**| ID of the order. | 
 **line_item_id** | **String**| ID of the line item. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Shipment get(shipment_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment_id = "shipment_id_example" # String | ID of the shipment.


begin
  result = api_instance.get(shipment_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment_id** | **String**| ID of the shipment. | 

### Return type

[**Shipment**](Shipment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get_item**
> ShipmentItem get_item(shipment_id, order_id, line_item_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment_id = "shipment_id_example" # String | ID of the shipment.

order_id = "order_id_example" # String | ID of the order.

line_item_id = "line_item_id_example" # String | ID of the line item.


begin
  result = api_instance.get_item(shipment_id, order_id, line_item_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->get_item: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment_id** | **String**| ID of the shipment. | 
 **order_id** | **String**| ID of the order. | 
 **line_item_id** | **String**| ID of the line item. | 

### Return type

[**ShipmentItem**](ShipmentItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListShipment list(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

opts = { 
  order_id: "order_id_example", # String | ID of the order.
  search: "search_example", # String | Search of the shipment.
  search_on: ["search_on_example"], # Array<String> | Search on of the shipment.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the shipment.
  page: 56, # Integer | Page of the shipment.
  page_size: 56, # Integer | Page size of the shipment.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the shipment.
}

begin
  result = api_instance.list(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **order_id** | **String**| ID of the order. | [optional] 
 **search** | **String**| Search of the shipment. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the shipment. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the shipment. | [optional] 
 **page** | **Integer**| Page of the shipment. | [optional] 
 **page_size** | **Integer**| Page size of the shipment. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the shipment. | [optional] 

### Return type

[**ListShipment**](ListShipment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_items**
> ListShipmentItem list_items(shipment_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment_id = "shipment_id_example" # String | ID of the shipment.

opts = { 
  search: "search_example", # String | Search of the shipment.
  search_on: ["search_on_example"], # Array<String> | Search on of the shipment.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the shipment.
  page: 56, # Integer | Page of the shipment.
  page_size: 56, # Integer | Page size of the shipment.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the shipment.
}

begin
  result = api_instance.list_items(shipment_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->list_items: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment_id** | **String**| ID of the shipment. | 
 **search** | **String**| Search of the shipment. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the shipment. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the shipment. | [optional] 
 **page** | **Integer**| Page of the shipment. | [optional] 
 **page_size** | **Integer**| Page size of the shipment. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the shipment. | [optional] 

### Return type

[**ListShipmentItem**](ListShipmentItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Shipment patch(shipment_id, shipment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment_id = "shipment_id_example" # String | ID of the shipment.

shipment = OrderCloud::Shipment.new # Shipment | 


begin
  result = api_instance.patch(shipment_id, shipment)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment_id** | **String**| ID of the shipment. | 
 **shipment** | [**Shipment**](Shipment.md)|  | 

### Return type

[**Shipment**](Shipment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_item**
> ShipmentItem save_item(shipment_id, item)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment_id = "shipment_id_example" # String | ID of the shipment.

item = OrderCloud::ShipmentItem.new # ShipmentItem | 


begin
  result = api_instance.save_item(shipment_id, item)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->save_item: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment_id** | **String**| ID of the shipment. | 
 **item** | [**ShipmentItem**](ShipmentItem.md)|  | 

### Return type

[**ShipmentItem**](ShipmentItem.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> Shipment update(shipment_id, shipment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::ShipmentApi.new

shipment_id = "shipment_id_example" # String | ID of the shipment.

shipment = OrderCloud::Shipment.new # Shipment | 


begin
  result = api_instance.update(shipment_id, shipment)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling ShipmentApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **shipment_id** | **String**| ID of the shipment. | 
 **shipment** | [**Shipment**](Shipment.md)|  | 

### Return type

[**Shipment**](Shipment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



