# OrderCloud::SpecApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](SpecApi.md#create) | **POST** /specs | 
[**create_option**](SpecApi.md#create_option) | **POST** /specs/{specID}/options | 
[**delete**](SpecApi.md#delete) | **DELETE** /specs/{specID} | 
[**delete_option**](SpecApi.md#delete_option) | **DELETE** /specs/{specID}/options/{optionID} | 
[**delete_product_assignment**](SpecApi.md#delete_product_assignment) | **DELETE** /specs/{specID}/productassignments/{productID} | 
[**get**](SpecApi.md#get) | **GET** /specs/{specID} | 
[**get_option**](SpecApi.md#get_option) | **GET** /specs/{specID}/options/{optionID} | 
[**list**](SpecApi.md#list) | **GET** /specs | 
[**list_options**](SpecApi.md#list_options) | **GET** /specs/{specID}/options | 
[**list_product_assignments**](SpecApi.md#list_product_assignments) | **GET** /specs/productassignments | 
[**patch**](SpecApi.md#patch) | **PATCH** /specs/{specID} | 
[**patch_option**](SpecApi.md#patch_option) | **PATCH** /specs/{specID}/options/{optionID} | 
[**save_product_assignment**](SpecApi.md#save_product_assignment) | **POST** /specs/productassignments | 
[**update**](SpecApi.md#update) | **PUT** /specs/{specID} | 
[**update_option**](SpecApi.md#update_option) | **PUT** /specs/{specID}/options/{optionID} | 


# **create**
> Spec create(spec)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec = OrderCloud::Spec.new # Spec | 


begin
  result = api_instance.create(spec)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec** | [**Spec**](Spec.md)|  | 

### Return type

[**Spec**](Spec.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **create_option**
> SpecOption create_option(spec_id, option)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

option = OrderCloud::SpecOption.new # SpecOption | 


begin
  result = api_instance.create_option(spec_id, option)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->create_option: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **option** | [**SpecOption**](SpecOption.md)|  | 

### Return type

[**SpecOption**](SpecOption.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(spec_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.


begin
  api_instance.delete(spec_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_option**
> delete_option(spec_id, option_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

option_id = "option_id_example" # String | ID of the option.


begin
  api_instance.delete_option(spec_id, option_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->delete_option: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **option_id** | **String**| ID of the option. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_product_assignment**
> delete_product_assignment(spec_id, product_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

product_id = "product_id_example" # String | ID of the product.


begin
  api_instance.delete_product_assignment(spec_id, product_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->delete_product_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **product_id** | **String**| ID of the product. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Spec get(spec_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.


begin
  result = api_instance.get(spec_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 

### Return type

[**Spec**](Spec.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get_option**
> SpecOption get_option(spec_id, option_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

option_id = "option_id_example" # String | ID of the option.


begin
  result = api_instance.get_option(spec_id, option_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->get_option: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **option_id** | **String**| ID of the option. | 

### Return type

[**SpecOption**](SpecOption.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListSpec list(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

opts = { 
  search: "search_example", # String | Search of the spec.
  search_on: ["search_on_example"], # Array<String> | Search on of the spec.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the spec.
  page: 56, # Integer | Page of the spec.
  page_size: 56, # Integer | Page size of the spec.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the spec.
}

begin
  result = api_instance.list(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search** | **String**| Search of the spec. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the spec. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the spec. | [optional] 
 **page** | **Integer**| Page of the spec. | [optional] 
 **page_size** | **Integer**| Page size of the spec. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the spec. | [optional] 

### Return type

[**ListSpec**](ListSpec.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_options**
> ListSpecOption list_options(spec_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

opts = { 
  search: "search_example", # String | Search of the spec.
  search_on: ["search_on_example"], # Array<String> | Search on of the spec.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the spec.
  page: 56, # Integer | Page of the spec.
  page_size: 56, # Integer | Page size of the spec.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the spec.
}

begin
  result = api_instance.list_options(spec_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->list_options: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **search** | **String**| Search of the spec. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the spec. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the spec. | [optional] 
 **page** | **Integer**| Page of the spec. | [optional] 
 **page_size** | **Integer**| Page size of the spec. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the spec. | [optional] 

### Return type

[**ListSpecOption**](ListSpecOption.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_product_assignments**
> ListSpecProductAssignment list_product_assignments(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

opts = { 
  search: "search_example", # String | Search of the spec.
  search_on: ["search_on_example"], # Array<String> | Search on of the spec.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the spec.
  page: 56, # Integer | Page of the spec.
  page_size: 56, # Integer | Page size of the spec.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the spec.
}

begin
  result = api_instance.list_product_assignments(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->list_product_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search** | **String**| Search of the spec. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the spec. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the spec. | [optional] 
 **page** | **Integer**| Page of the spec. | [optional] 
 **page_size** | **Integer**| Page size of the spec. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the spec. | [optional] 

### Return type

[**ListSpecProductAssignment**](ListSpecProductAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Spec patch(spec_id, spec)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

spec = OrderCloud::Spec.new # Spec | 


begin
  result = api_instance.patch(spec_id, spec)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **spec** | [**Spec**](Spec.md)|  | 

### Return type

[**Spec**](Spec.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch_option**
> SpecOption patch_option(spec_id, option_id, option)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

option_id = "option_id_example" # String | ID of the option.

option = OrderCloud::SpecOption.new # SpecOption | 


begin
  result = api_instance.patch_option(spec_id, option_id, option)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->patch_option: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **option_id** | **String**| ID of the option. | 
 **option** | [**SpecOption**](SpecOption.md)|  | 

### Return type

[**SpecOption**](SpecOption.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_product_assignment**
> save_product_assignment(product_assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

product_assignment = OrderCloud::SpecProductAssignment.new # SpecProductAssignment | 


begin
  api_instance.save_product_assignment(product_assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->save_product_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **product_assignment** | [**SpecProductAssignment**](SpecProductAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> Spec update(spec_id, spec)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

spec = OrderCloud::Spec.new # Spec | 


begin
  result = api_instance.update(spec_id, spec)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **spec** | [**Spec**](Spec.md)|  | 

### Return type

[**Spec**](Spec.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update_option**
> SpecOption update_option(spec_id, option_id, option)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpecApi.new

spec_id = "spec_id_example" # String | ID of the spec.

option_id = "option_id_example" # String | ID of the option.

option = OrderCloud::SpecOption.new # SpecOption | 


begin
  result = api_instance.update_option(spec_id, option_id, option)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpecApi->update_option: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **spec_id** | **String**| ID of the spec. | 
 **option_id** | **String**| ID of the option. | 
 **option** | [**SpecOption**](SpecOption.md)|  | 

### Return type

[**SpecOption**](SpecOption.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



