# OrderCloud::SpendingAccountApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](SpendingAccountApi.md#create) | **POST** /buyers/{buyerID}/spendingaccounts | 
[**delete**](SpendingAccountApi.md#delete) | **DELETE** /buyers/{buyerID}/spendingaccounts/{spendingAccountID} | 
[**delete_assignment**](SpendingAccountApi.md#delete_assignment) | **DELETE** /buyers/{buyerID}/spendingaccounts/{spendingAccountID}/assignments | 
[**get**](SpendingAccountApi.md#get) | **GET** /buyers/{buyerID}/spendingaccounts/{spendingAccountID} | 
[**list**](SpendingAccountApi.md#list) | **GET** /buyers/{buyerID}/spendingaccounts | 
[**list_assignments**](SpendingAccountApi.md#list_assignments) | **GET** /buyers/{buyerID}/spendingaccounts/assignments | 
[**patch**](SpendingAccountApi.md#patch) | **PATCH** /buyers/{buyerID}/spendingaccounts/{spendingAccountID} | 
[**save_assignment**](SpendingAccountApi.md#save_assignment) | **POST** /buyers/{buyerID}/spendingaccounts/assignments | 
[**update**](SpendingAccountApi.md#update) | **PUT** /buyers/{buyerID}/spendingaccounts/{spendingAccountID} | 


# **create**
> SpendingAccount create(buyer_id, spending_account)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

spending_account = OrderCloud::SpendingAccount.new # SpendingAccount | 


begin
  result = api_instance.create(buyer_id, spending_account)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **spending_account** | [**SpendingAccount**](SpendingAccount.md)|  | 

### Return type

[**SpendingAccount**](SpendingAccount.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(buyer_id, spending_account_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

spending_account_id = "spending_account_id_example" # String | ID of the spending account.


begin
  api_instance.delete(buyer_id, spending_account_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **spending_account_id** | **String**| ID of the spending account. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_assignment**
> delete_assignment(buyer_id, spending_account_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

spending_account_id = "spending_account_id_example" # String | ID of the spending account.

opts = { 
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example" # String | ID of the user group.
}

begin
  api_instance.delete_assignment(buyer_id, spending_account_id, opts)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->delete_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **spending_account_id** | **String**| ID of the spending account. | 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> SpendingAccount get(buyer_id, spending_account_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

spending_account_id = "spending_account_id_example" # String | ID of the spending account.


begin
  result = api_instance.get(buyer_id, spending_account_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **spending_account_id** | **String**| ID of the spending account. | 

### Return type

[**SpendingAccount**](SpendingAccount.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListSpendingAccount list(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  search: "search_example", # String | Search of the spending account.
  search_on: ["search_on_example"], # Array<String> | Search on of the spending account.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the spending account.
  page: 56, # Integer | Page of the spending account.
  page_size: 56, # Integer | Page size of the spending account.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the spending account.
}

begin
  result = api_instance.list(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **search** | **String**| Search of the spending account. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the spending account. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the spending account. | [optional] 
 **page** | **Integer**| Page of the spending account. | [optional] 
 **page_size** | **Integer**| Page size of the spending account. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the spending account. | [optional] 

### Return type

[**ListSpendingAccount**](ListSpendingAccount.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_assignments**
> ListSpendingAccountAssignment list_assignments(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  spending_account_id: "spending_account_id_example", # String | ID of the spending account.
  user_id: "user_id_example", # String | ID of the user.
  user_group_id: "user_group_id_example", # String | ID of the user group.
  level: "level_example", # String | Level of the spending account.
  page: 56, # Integer | Page of the spending account.
  page_size: 56 # Integer | Page size of the spending account.
}

begin
  result = api_instance.list_assignments(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->list_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **spending_account_id** | **String**| ID of the spending account. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **level** | **String**| Level of the spending account. | [optional] 
 **page** | **Integer**| Page of the spending account. | [optional] 
 **page_size** | **Integer**| Page size of the spending account. | [optional] 

### Return type

[**ListSpendingAccountAssignment**](ListSpendingAccountAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> SpendingAccount patch(buyer_id, spending_account_id, spending_account)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

spending_account_id = "spending_account_id_example" # String | ID of the spending account.

spending_account = OrderCloud::SpendingAccount.new # SpendingAccount | 


begin
  result = api_instance.patch(buyer_id, spending_account_id, spending_account)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **spending_account_id** | **String**| ID of the spending account. | 
 **spending_account** | [**SpendingAccount**](SpendingAccount.md)|  | 

### Return type

[**SpendingAccount**](SpendingAccount.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_assignment**
> save_assignment(buyer_id, assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

assignment = OrderCloud::SpendingAccountAssignment.new # SpendingAccountAssignment | 


begin
  api_instance.save_assignment(buyer_id, assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->save_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **assignment** | [**SpendingAccountAssignment**](SpendingAccountAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> SpendingAccount update(buyer_id, spending_account_id, spending_account)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SpendingAccountApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

spending_account_id = "spending_account_id_example" # String | ID of the spending account.

spending_account = OrderCloud::SpendingAccount.new # SpendingAccount | 


begin
  result = api_instance.update(buyer_id, spending_account_id, spending_account)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SpendingAccountApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **spending_account_id** | **String**| ID of the spending account. | 
 **spending_account** | [**SpendingAccount**](SpendingAccount.md)|  | 

### Return type

[**SpendingAccount**](SpendingAccount.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



