# OrderCloud::SupplierApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](SupplierApi.md#create) | **POST** /suppliers | 
[**delete**](SupplierApi.md#delete) | **DELETE** /suppliers/{supplierID} | 
[**get**](SupplierApi.md#get) | **GET** /suppliers/{supplierID} | 
[**list**](SupplierApi.md#list) | **GET** /suppliers | 
[**patch**](SupplierApi.md#patch) | **PATCH** /suppliers/{supplierID} | 
[**update**](SupplierApi.md#update) | **PUT** /suppliers/{supplierID} | 


# **create**
> Supplier create(company)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierApi.new

company = OrderCloud::Supplier.new # Supplier | 


begin
  result = api_instance.create(company)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **company** | [**Supplier**](Supplier.md)|  | 

### Return type

[**Supplier**](Supplier.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(supplier_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.


begin
  api_instance.delete(supplier_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> Supplier get(supplier_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.


begin
  result = api_instance.get(supplier_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 

### Return type

[**Supplier**](Supplier.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListSupplier list(opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierApi.new

opts = { 
  search: "search_example", # String | Search of the supplier.
  search_on: ["search_on_example"], # Array<String> | Search on of the supplier.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the supplier.
  page: 56, # Integer | Page of the supplier.
  page_size: 56, # Integer | Page size of the supplier.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the supplier.
}

begin
  result = api_instance.list(opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **search** | **String**| Search of the supplier. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the supplier. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the supplier. | [optional] 
 **page** | **Integer**| Page of the supplier. | [optional] 
 **page_size** | **Integer**| Page size of the supplier. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the supplier. | [optional] 

### Return type

[**ListSupplier**](ListSupplier.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> Supplier patch(supplier_id, company)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

company = OrderCloud::Supplier.new # Supplier | 


begin
  result = api_instance.patch(supplier_id, company)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **company** | [**Supplier**](Supplier.md)|  | 

### Return type

[**Supplier**](Supplier.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> Supplier update(supplier_id, company)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

company = OrderCloud::Supplier.new # Supplier | 


begin
  result = api_instance.update(supplier_id, company)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **company** | [**Supplier**](Supplier.md)|  | 

### Return type

[**Supplier**](Supplier.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



