# OrderCloud::SupplierUserApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](SupplierUserApi.md#create) | **POST** /suppliers/{supplierID}/users | 
[**delete**](SupplierUserApi.md#delete) | **DELETE** /suppliers/{supplierID}/users/{userID} | 
[**get**](SupplierUserApi.md#get) | **GET** /suppliers/{supplierID}/users/{userID} | 
[**get_access_token**](SupplierUserApi.md#get_access_token) | **POST** /suppliers/{supplierID}/users/{userID}/accesstoken | 
[**list**](SupplierUserApi.md#list) | **GET** /suppliers/{supplierID}/users | 
[**patch**](SupplierUserApi.md#patch) | **PATCH** /suppliers/{supplierID}/users/{userID} | 
[**update**](SupplierUserApi.md#update) | **PUT** /suppliers/{supplierID}/users/{userID} | 


# **create**
> User create(supplier_id, user)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user = OrderCloud::User.new # User | 


begin
  result = api_instance.create(supplier_id, user)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user** | [**User**](User.md)|  | 

### Return type

[**User**](User.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(supplier_id, user_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_id = "user_id_example" # String | ID of the user.


begin
  api_instance.delete(supplier_id, user_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_id** | **String**| ID of the user. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> User get(supplier_id, user_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_id = "user_id_example" # String | ID of the user.


begin
  result = api_instance.get(supplier_id, user_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_id** | **String**| ID of the user. | 

### Return type

[**User**](User.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get_access_token**
> AccessToken get_access_token(supplier_id, user_id, token_request)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_id = "user_id_example" # String | ID of the user.

token_request = OrderCloud::ImpersonateTokenRequest.new # ImpersonateTokenRequest | 


begin
  result = api_instance.get_access_token(supplier_id, user_id, token_request)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserApi->get_access_token: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_id** | **String**| ID of the user. | 
 **token_request** | [**ImpersonateTokenRequest**](ImpersonateTokenRequest.md)|  | 

### Return type

[**AccessToken**](AccessToken.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListUser list(supplier_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

opts = { 
  user_group_id: "user_group_id_example", # String | ID of the user group.
  search: "search_example", # String | Search of the supplier user.
  search_on: ["search_on_example"], # Array<String> | Search on of the supplier user.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the supplier user.
  page: 56, # Integer | Page of the supplier user.
  page_size: 56, # Integer | Page size of the supplier user.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the supplier user.
}

begin
  result = api_instance.list(supplier_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **search** | **String**| Search of the supplier user. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the supplier user. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the supplier user. | [optional] 
 **page** | **Integer**| Page of the supplier user. | [optional] 
 **page_size** | **Integer**| Page size of the supplier user. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the supplier user. | [optional] 

### Return type

[**ListUser**](ListUser.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> User patch(supplier_id, user_id, user)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_id = "user_id_example" # String | ID of the user.

user = OrderCloud::User.new # User | 


begin
  result = api_instance.patch(supplier_id, user_id, user)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_id** | **String**| ID of the user. | 
 **user** | [**User**](User.md)|  | 

### Return type

[**User**](User.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> User update(supplier_id, user_id, user)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_id = "user_id_example" # String | ID of the user.

user = OrderCloud::User.new # User | 


begin
  result = api_instance.update(supplier_id, user_id, user)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_id** | **String**| ID of the user. | 
 **user** | [**User**](User.md)|  | 

### Return type

[**User**](User.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



