# OrderCloud::SupplierUserGroupApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](SupplierUserGroupApi.md#create) | **POST** /suppliers/{supplierID}/usergroups | 
[**delete**](SupplierUserGroupApi.md#delete) | **DELETE** /suppliers/{supplierID}/usergroups/{userGroupID} | 
[**delete_user_assignment**](SupplierUserGroupApi.md#delete_user_assignment) | **DELETE** /suppliers/{supplierID}/usergroups/{userGroupID}/assignments/{userID} | 
[**get**](SupplierUserGroupApi.md#get) | **GET** /suppliers/{supplierID}/usergroups/{userGroupID} | 
[**list**](SupplierUserGroupApi.md#list) | **GET** /suppliers/{supplierID}/usergroups | 
[**list_user_assignments**](SupplierUserGroupApi.md#list_user_assignments) | **GET** /suppliers/{supplierID}/usergroups/assignments | 
[**patch**](SupplierUserGroupApi.md#patch) | **PATCH** /suppliers/{supplierID}/usergroups/{userGroupID} | 
[**save_user_assignment**](SupplierUserGroupApi.md#save_user_assignment) | **POST** /suppliers/{supplierID}/usergroups/assignments | 
[**update**](SupplierUserGroupApi.md#update) | **PUT** /suppliers/{supplierID}/usergroups/{userGroupID} | 


# **create**
> UserGroup create(supplier_id, group)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

group = OrderCloud::UserGroup.new # UserGroup | 


begin
  result = api_instance.create(supplier_id, group)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **group** | [**UserGroup**](UserGroup.md)|  | 

### Return type

[**UserGroup**](UserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(supplier_id, user_group_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_group_id = "user_group_id_example" # String | ID of the user group.


begin
  api_instance.delete(supplier_id, user_group_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_group_id** | **String**| ID of the user group. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_user_assignment**
> delete_user_assignment(supplier_id, user_group_id, user_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_group_id = "user_group_id_example" # String | ID of the user group.

user_id = "user_id_example" # String | ID of the user.


begin
  api_instance.delete_user_assignment(supplier_id, user_group_id, user_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->delete_user_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_group_id** | **String**| ID of the user group. | 
 **user_id** | **String**| ID of the user. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> UserGroup get(supplier_id, user_group_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_group_id = "user_group_id_example" # String | ID of the user group.


begin
  result = api_instance.get(supplier_id, user_group_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_group_id** | **String**| ID of the user group. | 

### Return type

[**UserGroup**](UserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListUserGroup list(supplier_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

opts = { 
  search: "search_example", # String | Search of the supplier user group.
  search_on: ["search_on_example"], # Array<String> | Search on of the supplier user group.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the supplier user group.
  page: 56, # Integer | Page of the supplier user group.
  page_size: 56, # Integer | Page size of the supplier user group.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the supplier user group.
}

begin
  result = api_instance.list(supplier_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **search** | **String**| Search of the supplier user group. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the supplier user group. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the supplier user group. | [optional] 
 **page** | **Integer**| Page of the supplier user group. | [optional] 
 **page_size** | **Integer**| Page size of the supplier user group. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the supplier user group. | [optional] 

### Return type

[**ListUserGroup**](ListUserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_user_assignments**
> ListUserGroupAssignment list_user_assignments(supplier_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

opts = { 
  user_group_id: "user_group_id_example", # String | ID of the user group.
  user_id: "user_id_example", # String | ID of the user.
  page: 56, # Integer | Page of the supplier user group.
  page_size: 56 # Integer | Page size of the supplier user group.
}

begin
  result = api_instance.list_user_assignments(supplier_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->list_user_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **page** | **Integer**| Page of the supplier user group. | [optional] 
 **page_size** | **Integer**| Page size of the supplier user group. | [optional] 

### Return type

[**ListUserGroupAssignment**](ListUserGroupAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> UserGroup patch(supplier_id, user_group_id, group)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_group_id = "user_group_id_example" # String | ID of the user group.

group = OrderCloud::UserGroup.new # UserGroup | 


begin
  result = api_instance.patch(supplier_id, user_group_id, group)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_group_id** | **String**| ID of the user group. | 
 **group** | [**UserGroup**](UserGroup.md)|  | 

### Return type

[**UserGroup**](UserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_user_assignment**
> save_user_assignment(supplier_id, user_group_assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_group_assignment = OrderCloud::UserGroupAssignment.new # UserGroupAssignment | 


begin
  api_instance.save_user_assignment(supplier_id, user_group_assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->save_user_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_group_assignment** | [**UserGroupAssignment**](UserGroupAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> UserGroup update(supplier_id, user_group_id, group)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::SupplierUserGroupApi.new

supplier_id = "supplier_id_example" # String | ID of the supplier.

user_group_id = "user_group_id_example" # String | ID of the user group.

group = OrderCloud::UserGroup.new # UserGroup | 


begin
  result = api_instance.update(supplier_id, user_group_id, group)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling SupplierUserGroupApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **supplier_id** | **String**| ID of the supplier. | 
 **user_group_id** | **String**| ID of the user group. | 
 **group** | [**UserGroup**](UserGroup.md)|  | 

### Return type

[**UserGroup**](UserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



