# OrderCloud::UserGroupApi

All URIs are relative to *https://api.ordercloud.io/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](UserGroupApi.md#create) | **POST** /buyers/{buyerID}/usergroups | 
[**delete**](UserGroupApi.md#delete) | **DELETE** /buyers/{buyerID}/usergroups/{userGroupID} | 
[**delete_user_assignment**](UserGroupApi.md#delete_user_assignment) | **DELETE** /buyers/{buyerID}/usergroups/{userGroupID}/assignments/{userID} | 
[**get**](UserGroupApi.md#get) | **GET** /buyers/{buyerID}/usergroups/{userGroupID} | 
[**list**](UserGroupApi.md#list) | **GET** /buyers/{buyerID}/usergroups | 
[**list_user_assignments**](UserGroupApi.md#list_user_assignments) | **GET** /buyers/{buyerID}/usergroups/assignments | 
[**patch**](UserGroupApi.md#patch) | **PATCH** /buyers/{buyerID}/usergroups/{userGroupID} | 
[**save_user_assignment**](UserGroupApi.md#save_user_assignment) | **POST** /buyers/{buyerID}/usergroups/assignments | 
[**update**](UserGroupApi.md#update) | **PUT** /buyers/{buyerID}/usergroups/{userGroupID} | 


# **create**
> UserGroup create(buyer_id, group)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

group = OrderCloud::UserGroup.new # UserGroup | 


begin
  result = api_instance.create(buyer_id, group)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->create: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **group** | [**UserGroup**](UserGroup.md)|  | 

### Return type

[**UserGroup**](UserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete**
> delete(buyer_id, user_group_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

user_group_id = "user_group_id_example" # String | ID of the user group.


begin
  api_instance.delete(buyer_id, user_group_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **user_group_id** | **String**| ID of the user group. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **delete_user_assignment**
> delete_user_assignment(buyer_id, user_group_id, user_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

user_group_id = "user_group_id_example" # String | ID of the user group.

user_id = "user_id_example" # String | ID of the user.


begin
  api_instance.delete_user_assignment(buyer_id, user_group_id, user_id)
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->delete_user_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **user_group_id** | **String**| ID of the user group. | 
 **user_id** | **String**| ID of the user. | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **get**
> UserGroup get(buyer_id, user_group_id)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

user_group_id = "user_group_id_example" # String | ID of the user group.


begin
  result = api_instance.get(buyer_id, user_group_id)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **user_group_id** | **String**| ID of the user group. | 

### Return type

[**UserGroup**](UserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list**
> ListUserGroup list(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  search: "search_example", # String | Search of the user group.
  search_on: ["search_on_example"], # Array<String> | Search on of the user group.
  sort_by: ["sort_by_example"], # Array<String> | Sort by of the user group.
  page: 56, # Integer | Page of the user group.
  page_size: 56, # Integer | Page size of the user group.
  filters: {'key' => "filters_example"} # Hash<String, String> | Filters of the user group.
}

begin
  result = api_instance.list(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->list: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **search** | **String**| Search of the user group. | [optional] 
 **search_on** | [**Array&lt;String&gt;**](String.md)| Search on of the user group. | [optional] 
 **sort_by** | [**Array&lt;String&gt;**](String.md)| Sort by of the user group. | [optional] 
 **page** | **Integer**| Page of the user group. | [optional] 
 **page_size** | **Integer**| Page size of the user group. | [optional] 
 **filters** | [**Hash&lt;String, String&gt;**](String.md)| Filters of the user group. | [optional] 

### Return type

[**ListUserGroup**](ListUserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **list_user_assignments**
> ListUserGroupAssignment list_user_assignments(buyer_id, opts)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

opts = { 
  user_group_id: "user_group_id_example", # String | ID of the user group.
  user_id: "user_id_example", # String | ID of the user.
  page: 56, # Integer | Page of the user group.
  page_size: 56 # Integer | Page size of the user group.
}

begin
  result = api_instance.list_user_assignments(buyer_id, opts)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->list_user_assignments: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **user_group_id** | **String**| ID of the user group. | [optional] 
 **user_id** | **String**| ID of the user. | [optional] 
 **page** | **Integer**| Page of the user group. | [optional] 
 **page_size** | **Integer**| Page size of the user group. | [optional] 

### Return type

[**ListUserGroupAssignment**](ListUserGroupAssignment.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **patch**
> UserGroup patch(buyer_id, user_group_id, group)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

user_group_id = "user_group_id_example" # String | ID of the user group.

group = OrderCloud::UserGroup.new # UserGroup | 


begin
  result = api_instance.patch(buyer_id, user_group_id, group)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->patch: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **user_group_id** | **String**| ID of the user group. | 
 **group** | [**UserGroup**](UserGroup.md)|  | 

### Return type

[**UserGroup**](UserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **save_user_assignment**
> save_user_assignment(buyer_id, user_group_assignment)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

user_group_assignment = OrderCloud::UserGroupAssignment.new # UserGroupAssignment | 


begin
  api_instance.save_user_assignment(buyer_id, user_group_assignment)
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->save_user_assignment: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **user_group_assignment** | [**UserGroupAssignment**](UserGroupAssignment.md)|  | 

### Return type

nil (empty response body)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



# **update**
> UserGroup update(buyer_id, user_group_id, group)



### Example
```ruby
# load the gem
require 'order_cloud'
# setup authorization
OrderCloud.configure do |config|
  # Configure OAuth2 access token for authorization: oauth2
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = OrderCloud::UserGroupApi.new

buyer_id = "buyer_id_example" # String | ID of the buyer.

user_group_id = "user_group_id_example" # String | ID of the user group.

group = OrderCloud::UserGroup.new # UserGroup | 


begin
  result = api_instance.update(buyer_id, user_group_id, group)
  p result
rescue OrderCloud::ApiError => e
  puts "Exception when calling UserGroupApi->update: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **buyer_id** | **String**| ID of the buyer. | 
 **user_group_id** | **String**| ID of the user group. | 
 **group** | [**UserGroup**](UserGroup.md)|  | 

### Return type

[**UserGroup**](UserGroup.md)

### Authorization

[oauth2](../README.md#oauth2)

### HTTP request headers

 - **Content-Type**: application/json, text/plain; charset=utf-8
 - **Accept**: application/json



